==> haskell-bifunctors-5.6-99-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bifunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bifunctors
version:              5.6
visibility:           public
id:                   bifunctors-5.6-K6PUy59ylq426ZXT29Buli
key:                  bifunctors-5.6-K6PUy59ylq426ZXT29Buli
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/bifunctors/
synopsis:             Bifunctors
description:          Bifunctors.
category:             Data, Functors
abi:                  a6de454b7c8c401b70bf0da86cfae412
exposed:              True
exposed-modules:
    Data.Biapplicative Data.Bifunctor.Biap Data.Bifunctor.Biff
    Data.Bifunctor.Clown Data.Bifunctor.Fix Data.Bifunctor.Flip
    Data.Bifunctor.Functor Data.Bifunctor.Join Data.Bifunctor.Joker
    Data.Bifunctor.Product Data.Bifunctor.Sum Data.Bifunctor.TH
    Data.Bifunctor.Tannen Data.Bifunctor.Wrapped

hidden-modules:       Data.Bifunctor.TH.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/bifunctors-5.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/bifunctors-5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bifunctors
hs-libraries:         HSbifunctors-5.6-K6PUy59ylq426ZXT29Buli
depends:
    base-4.16.4.0 comonad-5.0.8-CZGmUOvuZnLIadrIFOwLfh
    containers-0.6.5.1
    foldable1-classes-compat-0.1-6IK4F1cnnUJ4QHLGiru9zA
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg template-haskell-2.18.0.0
    th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html:         /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bifunctors-5.6-101-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bifunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bifunctors
version:              5.6
visibility:           public
id:                   bifunctors-5.6-24PtXDCU2m5EbKOhSIeuUk
key:                  bifunctors-5.6-24PtXDCU2m5EbKOhSIeuUk
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/bifunctors/
synopsis:             Bifunctors
description:          Bifunctors.
category:             Data, Functors
abi:                  b11dc651052184b0f59e7ae0626077ed
exposed:              True
exposed-modules:
    Data.Biapplicative Data.Bifunctor.Biap Data.Bifunctor.Biff
    Data.Bifunctor.Clown Data.Bifunctor.Fix Data.Bifunctor.Flip
    Data.Bifunctor.Functor Data.Bifunctor.Join Data.Bifunctor.Joker
    Data.Bifunctor.Product Data.Bifunctor.Sum Data.Bifunctor.TH
    Data.Bifunctor.Tannen Data.Bifunctor.Wrapped

hidden-modules:       Data.Bifunctor.TH.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/bifunctors-5.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/bifunctors-5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bifunctors
hs-libraries:         HSbifunctors-5.6-24PtXDCU2m5EbKOhSIeuUk
depends:
    base-4.16.4.0 comonad-5.0.8-7SvbYtos92D1jPcdvHdUhM
    containers-0.6.5.1
    foldable1-classes-compat-0.1-GEd1GZQ6gouAPGbQzBF8pb
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg template-haskell-2.18.0.0
    th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html:         /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
